@@ -21,13 +21,14 @@
 
 from datetime import datetime
 
-class GlancesAttribute(object):
 
+class GlancesAttribute(object):
     def __init__(self, name, description='', history_max_size=None):
         """Init the attribute
-        name: Attribute name (string)
-        description: Attribute human reading description (string)
-        history_max_size: Maximum size of the history list (default is no limit)
+
+        :param name: Attribute name (string)
+        :param description: Attribute human reading description (string)
+        :param history_max_size: Maximum size of the history list (default is no limit)
 
         History is stored as a list for tuple: [(date, value), ...]
         """
@@ -46,6 +47,7 @@ class GlancesAttribute(object):
     """
     Properties for the attribute name
     """
+
     @property
     def name(self):
         return self._name
@@ -57,6 +59,7 @@ class GlancesAttribute(object):
     """
     Properties for the attribute description
     """
+
     @property
     def description(self):
         return self._description
@@ -68,6 +71,7 @@ class GlancesAttribute(object):
     """
     Properties for the attribute value
     """
+
     @property
     def value(self):
         if self.history_len() > 0:
@@ -78,6 +82,7 @@ class GlancesAttribute(object):
     @value.setter
     def value(self, new_value):
         """Set a value.
+
         Value is a tuple: (<timestamp>, <new_value>)
         """
         self._value = (datetime.now(), new_value)
@@ -86,6 +91,7 @@ class GlancesAttribute(object):
     """
     Properties for the attribute history
     """
+
     @property
     def history(self):
         return self._history
@@ -102,25 +108,23 @@ class GlancesAttribute(object):
         self._history = []
 
     def history_add(self, value):
-        """Add a value in the history
-        """
+        """Add a value in the history"""
         if self._history_max_size:
             if self.history_len() >= self._history_max_size:
                 self._history.pop(0)
             self._history.append(value)
 
     def history_size(self):
-        """Return the history size (maximum nuber of value in the history)
-        """
+        """Return the history size (maximum number of value in the history)"""
         return len(self._history)
 
     def history_len(self):
-        """Return the current history lenght
-        """
+        """Return the current history length"""
         return len(self._history)
 
     def history_value(self, pos=1):
         """Return the value in position pos in the history.
+
         Default is to return the latest value added to the history.
         """
         return self._history[-pos]
@@ -134,7 +138,6 @@ class GlancesAttribute(object):
         return [(i[0].isoformat(), i[1]) for i in self._history[-nb:]]
 
     def history_mean(self, nb=5):
-        """Return the mean on the <nb> values in the history.
-        """
+        """Return the mean on the <nb> values in the history."""
         _, v = zip(*self._history)
         return sum(v[-nb:]) / float(v[-1] - v[-nb])
