@@ -17,8 +17,10 @@ export default function GlancesPluginDockerController($scope, GlancesStats) {
                 'id': containerData.Id,
                 'name': containerData.name,
                 'status': containerData.Status,
+                'uptime': containerData.Uptime,
                 'cpu': containerData.cpu.total,
                 'memory': containerData.memory.usage != undefined ? containerData.memory.usage : '?',
+                'rss': containerData.memory.rss != undefined ? containerData.memory.rss : '?',
                 'ior': containerData.io.ior != undefined ? containerData.io.ior : '?',
                 'iow': containerData.io.iow != undefined ? containerData.io.iow : '?',
                 'io_time_since_update': containerData.io.time_since_update,
